@@ -16,4 +16,4 @@ alembic upgrade head
 
 echo "Backend"
 echo "==============="
-uvicorn main:app --host 0.0.0.0 --port 5000 --reload
+python main.py
